Struct GetQuiz
pub struct GetQuiz {
pub uri: Option<DocumentUri>,
pub rp: Option<String>,
pub a: Option<ArchiveId>,
pub p: Option<String>,
pub d: Option<String>,
pub l: Option<Language>,
}Expand description
Serialized arguments for the get_quiz server function.
Fields
uri: Option<DocumentUri>rp: Option<String>a: Option<ArchiveId>p: Option<String>d: Option<String>l: Option<Language>Trait Implementations
impl<'de> Deserialize<'de> for GetQuiz
impl<'de> Deserialize<'de> for GetQuiz
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetQuiz, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetQuiz, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Serialize for GetQuiz
impl Serialize for GetQuiz
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl ServerFn for GetQuiz
impl ServerFn for GetQuiz
const PATH: &'static str
const PATH: &'static str
A unique path for the server function’s API endpoint, relative to the host, including its prefix.
type Client = BrowserClient
type Client = BrowserClient
The type of the HTTP client that will send the request from the client side. Read more
type Server = AxumServerFnBackend
type Server = AxumServerFnBackend
The type of the HTTP server that will send the response from the server side. Read more
type Protocol = Http<GetUrl, Post<JsonEncoding>>
type Protocol = Http<GetUrl, Post<JsonEncoding>>
The protocol the server function uses to communicate with the client.
type Output = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Ok
type Output = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Ok
The return type of the server function. Read more
type Error = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Err
type Error = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Err
The type of error in the server function return.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].type InputStreamError = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Err
type InputStreamError = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Err
The type of error in the server function for stream items sent from the client to the server.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].type OutputStreamError = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Err
type OutputStreamError = <Result<Quiz, ServerFnError<String>> as ServerFnMustReturnResult>::Err
The type of error in the server function for stream items sent from the server to the client.
Typically [
ServerFnError], but allowed to be any type that implements [FromServerFnError].fn middlewares() -> Vec<Arc<dyn Layer<<<GetQuiz as ServerFn>::Server as Server<<GetQuiz as ServerFn>::Error>>::Request, <<GetQuiz as ServerFn>::Server as Server<<GetQuiz as ServerFn>::Error>>::Response>>>
fn middlewares() -> Vec<Arc<dyn Layer<<<GetQuiz as ServerFn>::Server as Server<<GetQuiz as ServerFn>::Error>>::Request, <<GetQuiz as ServerFn>::Server as Server<<GetQuiz as ServerFn>::Error>>::Response>>>
Middleware that should be applied to this server function.